@@ -9,7 +9,7 @@ use Carp qw( croak carp );
 use POSIX ":sys_wait_h";
 use IO::Pipe;
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 sub new {
     my $class = shift;
@@ -74,6 +74,11 @@ sub run {
     return $self->{_daemon}->run;
 }
 
+sub daemon {
+    my ($self) = @_;
+    return $self->{_daemon};
+}
+
 sub _parent {
     my ( $daemon, $self ) = @_;
 
@@ -317,7 +322,7 @@ Daemon::Device - Forking daemon device construct
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Daemon-Device.svg)](https://travis-ci.org/gryphonshafer/Daemon-Device)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Daemon-Device/badge.png)](https://coveralls.io/r/gryphonshafer/Daemon-Device)
@@ -547,6 +552,11 @@ The C<run()> method calls the method of the same name from L<Daemon::Control>.
 This will make your program act like an init file, accepting input from the
 command line. Run will exit with 0 for success and uses LSB exit codes.
 
+=head2 daemon
+
+If you need to access the L<Daemon::Control> object inside the device, you can
+do so with the C<daemon()> method.
+
 =head2 ppid, cpid
 
 These methods return the parent PID or child PID. From both parent processes
